# Change Log

<!-- <START NEW CHANGELOG ENTRY> -->

## 0.7.0

([Full Changelog](https://github.com/jupyterlab/pytest-check-links/compare/v0.6.0...3468259d8cd5b3becccb406bdc83c4611ade8f26))

### Enhancements made

- Update for pytest 7 [#44](https://github.com/jupyterlab/pytest-check-links/pull/44) ([@blink1073](https://github.com/blink1073))

### Maintenance and upkeep improvements

- Add flake8 and mypy linting [#46](https://github.com/jupyterlab/pytest-check-links/pull/46) ([@blink1073](https://github.com/blink1073))
- Apply Auto Formatting [#45](https://github.com/jupyterlab/pytest-check-links/pull/45) ([@blink1073](https://github.com/blink1073))
- Enforce labels on PRs [#43](https://github.com/jupyterlab/pytest-check-links/pull/43) ([@blink1073](https://github.com/blink1073))
- Update for Jupyter Releaser [#42](https://github.com/jupyterlab/pytest-check-links/pull/42) ([@blink1073](https://github.com/blink1073))

### Documentation improvements

- Add changelog entry for 0.6.0 [#41](https://github.com/jupyterlab/pytest-check-links/pull/41) ([@blink1073](https://github.com/blink1073))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/jupyterlab/pytest-check-links/graphs/contributors?from=2021-10-19&to=2022-04-07&type=c))

[@blink1073](https://github.com/search?q=repo%3Ajupyterlab%2Fpytest-check-links+involves%3Ablink1073+updated%3A2021-10-19..2022-04-07&type=Issues) | [@codecov](https://github.com/search?q=repo%3Ajupyterlab%2Fpytest-check-links+involves%3Acodecov+updated%3A2021-10-19..2022-04-07&type=Issues)

<!-- <END NEW CHANGELOG ENTRY> -->

## 0.6.0

- Handle ignore links for `ipynb` files [#39](https://github.com/jupyterlab/pytest-check-links/pull/39) ([@pratyakshajha](https://github.com/pratyakshajha))
- Drop support for Python 3.6 and add support for Python 3.10 [#40](https://github.com/jupyterlab/pytest-check-links/pull/40) ([@blink1073](https://github.com/blink1073))

## 0.5.2

- Handle attachments in notebook cells [#36](https://github.com/jupyterlab/pytest-check-links/pull/36) ([@jtpio](https://github.com/jtpio))

## 0.5.1

- Fix handling of Nested RST links [#33](https://github.com/jupyterlab/pytest-check-links/pull/33) ([@jtpio](https://github.com/jtpio))
- Fix check-links-ignore example in Readme [#32](https://github.com/jupyterlab/pytest-check-links/pull/32) ([@blink1073](https://github.com/blink1073))

## 0.5.0

- Add Ability to Ignore Link Patterns [#30](https://github.com/jupyterlab/pytest-check-links/pull/30) ([@afshin](https://github.com/afshin))
- Test with python 3.9 in CI, deal with some windows issues [#27](https://github.com/jupyterlab/pytest-check-links/pull/27) ([@bollwyvl](https://github.com/bollwyvl))

## 0.4.4

- Remove defunct Travis CI [#24](https://github.com/jupyterlab/pytest-check-links/pull/24) ([@afshin](https://github.com/afshin))

## 0.4.3

- Update for recommended usage of CheckLinks [#22](https://github.com/jupyterlab/pytest-check-links/pull/22)

## 0.4.2

- Another improvement to retry logic [#20](https://github.com/jupyterlab/pytest-check-links/pull/20)

## 0.4.1

- Clean up metadata for dist generation [#19](https://github.com/jupyterlab/pytest-check-links/pull/19)
- Improve retry logic and add python 3 classifier [#18](https://github.com/jupyterlab/pytest-check-links/pull/18)

## 0.4.0

- Drop py27 support and add badges [#15](https://github.com/jupyterlab/pytest-check-links/pull/15)
- Use requests(-cache) [#12](https://github.com/jupyterlab/pytest-check-links/pull/12)
- Add checking of self- and local html anchors [#10](https://github.com/jupyterlab/pytest-check-links/pull/10)

## 0.3.0

- Honor Retry-After Header [#9](https://github.com/jupyterlab/pytest-check-links/pull/9)
- Update metadata for JupyterLab Org [#7](https://github.com/jupyterlab/pytest-check-links/pull/7)

## 0.2.0

- Add rst handling [#4](https://github.com/jupyterlab/pytest-check-links/pull/4)
